@@ -52,6 +52,8 @@ static McHashTable<const char *, char *> *cxxtable;
 static McHashTable<const char *, char *> *javatable;
 static McHashTable<const char *, char *> *idltable;
 
+static McHashTable<const char*, Entry*>	namespace_roots(0);
+
 // Simple round robin cache for `fastNotSmall == true'
 static int cache_pos = 0;
 // So we can remember blanks as well
@@ -78,6 +80,14 @@ bool mergeEntry(Entry *ccentry);
 void mergeEntries(Entry *root);
 void getRefNames(McDArray<McString*> strings, const char *names);
 
+void addNamespace(Entry* entry)
+{
+    Entry**	e = namespace_roots.lookup(entry->fullName.c_str());
+
+    if(e == 0)
+        namespace_roots[entry->fullName.c_str()] = entry;
+}
+
 Entry::Entry()
 {
     static int n = 1;
@@ -1307,6 +1317,24 @@ Entry *getRefEntry(McString &name, Entry *entry)
 		}
 	    }
 
+    if(!result && language == LANG_CXX)
+	{
+        // Search for fully-qualified identifiers in top-level namespaces
+        namespace_roots.resetIter();
+
+        const char*	key;
+        Entry*		value;
+
+        while(!result && namespace_roots.next(key, value))
+	    {
+            fullName = value->fullName;
+            fullName += "::";
+            fullName += name;
+
+            result = searchRefEntry(fullName, value);
+	    }
+	}
+
     return result;
 }
 
@@ -1420,3 +1448,18 @@ void reNumber(Entry *tp)
 	if(!MAKE_DOC(tmp))
 	    tmp->subnumber = i++;
 }
+
+bool relevantClassGraphs(Entry *tmp)
+{
+    for(; tmp; tmp = tmp->next)
+	{
+	if((tmp->section & CLASS_SEC) &&
+	    tmp->proBaseclasses.size() == 0 &&
+	    tmp->pubBaseclasses.size() == 0)
+	    return true;
+	if(relevantClassGraphs(tmp->sub))
+	    return true;
+	}
+
+    return false;
+}
