@@ -31,6 +31,7 @@
 #include "McHashTable.h"
 #include "McString.h"
 #include "config.h"
+#include "portability.h"
 
 #ifdef ENABLE_NLS
 #include <libintl.h>
@@ -39,7 +40,7 @@
 #define _(x) (x)
 #endif
 
-#define DOCXX_VERSION	"3.4.6"
+#define DOCXX_VERSION	"3.4.7"
 
 extern FILE			*out;			// output FILE
 extern char			language;		// language
@@ -344,6 +345,7 @@ extern void	mergeEntries(Entry *root);
 extern int	getNumChildren(Entry *tp);
 extern void	checkPackages(Entry *tp);
 extern void	reNumber(Entry *tp);
+extern bool	relevantClassGraphs(Entry *tmp);
 
 extern void	readfile(McString *in, const char *file, int startLine,
 		    const McString& directory = "", int scanSubDirs = 0);
@@ -383,6 +385,7 @@ extern void	readfile(McString *in, const char *file, int startLine,
 	((entry->parent != 0 &&					\
 	(entry->parent->section == CLASS_SEC ||			\
 	entry->parent->section == UNION_SEC ||			\
+	entry->parent->section == TYPEDEF_SEC ||		\
 	entry->parent->section == INTERFACE_SEC ||		\
 	entry->parent->section == PACKAGE_SEC ||		\
 	entry->parent->section == NAMESPACE_SEC)) ?		\
