@@ -128,9 +128,14 @@ void buildHeaders()
 // Initializes HTML footers
 void buildFooters()
 {
-    indexFooter =	"<P><I><A HREF=\"HIER";
-    indexFooter +=	htmlSuffix;
-    indexFooter +=	_("\">Hierarchy of classes</A></I></P>");
+    bool generateClassGraphs = !noClassGraph && relevantClassGraphs(root);
+
+    if(generateClassGraphs)
+	{
+	indexFooter =	"<P><I><A HREF=\"HIER";
+	indexFooter +=	htmlSuffix;
+	indexFooter +=	_("\">Hierarchy of classes</A></I></P>");
+	}
 
     hierFooter =	"<P><I><A HREF=\"index";
     hierFooter +=	htmlSuffix;
@@ -139,19 +144,27 @@ void buildFooters()
     pageFooter =	"<P><I><A HREF=\"index";
     pageFooter +=	htmlSuffix;
     pageFooter +=	_("\">Alphabetic index</A></I>");
-    pageFooter +=	" <I><A HREF=\"HIER";
-    pageFooter +=	htmlSuffix;
-    pageFooter +=	_("\">Hierarchy of classes</A></I></P>");
+    if(generateClassGraphs)
+	{
+	pageFooter +=	" <I><A HREF=\"HIER";
+	pageFooter +=	htmlSuffix;
+	pageFooter +=	_("\">Hierarchy of classes</A></I>");
+	}
+    pageFooter +=	"</P>";
 
     pageFooterJava =	"<P><I><A HREF=\"index";
     pageFooterJava +=	htmlSuffix;
     pageFooterJava +=	_("\">Alphabetic index</A></I>");
-    pageFooterJava +=	" <I><A HREF=\"HIER";
-    pageFooterJava +=	htmlSuffix;
-    pageFooterJava +=	_("\">HTML hierarchy of classes</A>");
-    pageFooterJava +=	_(" or <A HREF=\"HIERjava");
-    pageFooterJava +=	htmlSuffix;
-    pageFooterJava +=	"\">Java</A></I></P>";
+    if(generateClassGraphs)
+	{
+	pageFooterJava +=	" <I><A HREF=\"HIER";
+	pageFooterJava +=	htmlSuffix;
+	pageFooterJava +=	_("\">HTML hierarchy of classes</A>");
+	pageFooterJava +=	_(" or <A HREF=\"HIERjava");
+	pageFooterJava +=	htmlSuffix;
+	pageFooterJava +=	"\">Java</A></I>";
+	}
+    pageFooterJava +=	"</P>";
 }
 
 McString makeFileName(const McString& str, Entry *e)
@@ -458,6 +471,7 @@ void TOClist::addEntry(Entry *entry, TOClist *tl)
 	    entry->parent->section == NAMESPACE_SEC ||
 	    (entry->parent->section == INTERFACE_SEC && language == LANG_IDL) ||
 	    entry->parent->section == UNION_SEC ||
+	    entry->parent->section == TYPEDEF_SEC ||
 	    (entry->parent->section == MANUAL_SEC && entry->parent != root))
 	    return;
 
@@ -1153,18 +1167,15 @@ void showMembers(Entry *e, FILE *f, int links, MemberList *ignore = 0)
 	int protection;
 	int secMask;
     } sections[] = {
-      { _("<DT><H3>Public Classes</H3><DD>"), PUBL, CLASS_SEC | UNION_SEC },
       { _("<DT><H3>Public Fields</H3><DD>"), PUBL, VARIABLE_SEC },
       { _("<DT><H3>Public Methods</H3><DD>"), PUBL, FUNCTION_SEC},
-      { _("<DT><H3>Public</H3><DD>"), PUBL, ~(CLASS_SEC | VARIABLE_SEC | FUNCTION_SEC | UNION_SEC) },
-      { _("<DT><H3>Protected Classes</H3><DD>"), PROT, CLASS_SEC | UNION_SEC },
+      { _("<DT><H3>Public Members</H3><DD>"), PUBL, ~(VARIABLE_SEC | FUNCTION_SEC) },
       { _("<DT><H3>Protected Fields</H3><DD>"), PROT, VARIABLE_SEC },
       { _("<DT><H3>Protected Methods</H3><DD>"), PROT, FUNCTION_SEC },
-      { _("<DT><H3>Protected</H3><DD>"), PROT, ~(CLASS_SEC | VARIABLE_SEC | FUNCTION_SEC | UNION_SEC) },
-      { _("<DT><H3>Private Classes</H3><DD>"), PRIV, CLASS_SEC | UNION_SEC },
+      { _("<DT><H3>Protected Members</H3><DD>"), PROT, ~(VARIABLE_SEC | FUNCTION_SEC) },
       { _("<DT><H3>Private Fields</H3><DD>"), PRIV, VARIABLE_SEC },
       { _("<DT><H3>Private Methods</H3><DD>"), PRIV, FUNCTION_SEC },
-      { _("<DT><H3>Private</H3><DD>"), PRIV, ~(CLASS_SEC | VARIABLE_SEC | FUNCTION_SEC | UNION_SEC) },
+      { _("<DT><H3>Private Members</H3><DD>"), PRIV, ~(VARIABLE_SEC | FUNCTION_SEC) },
       { 0, 0, 0 }};
 
     int i;
@@ -1490,8 +1501,27 @@ void writeHeader(Entry *e, FILE *f)
 	else
             {
 	    blank_len = strlen(e->htype) + strlen(ENTRY_NAME(e).c_str()) + 1;
-	    fprintf(f, "%s <A HREF=\"#DOC.DOCU\">%s", e->htype,
-		ENTRY_NAME(e).c_str());
+	    fprintf(f, "%s <A HREF=\"#DOC.DOCU\">", e->htype);
+            if(e->section == CLASS_SEC ||
+        	e->section == NAMESPACE_SEC ||
+        	e->section == TYPEDEF_SEC ||
+                e->section == UNION_SEC)
+		{
+                char	buf0[256], buf1[256];
+
+                Entry*	p = e->parent;
+                sprintf(buf0, e->name.c_str());
+                while(p != 0 && p->section == NAMESPACE_SEC)
+		    {
+                    sprintf(buf1, "%s::%s", p->name.c_str(), buf0);
+                    strcpy(buf0, buf1);
+                    p = p->parent;
+        	    }
+
+                fprintf(f, "%s", buf0);
+		}
+	    else
+                fprintf(f, "%s", ENTRY_NAME(e).c_str());
 	    }
 
 	fprintf(f, "</A></H2>");
@@ -2131,7 +2161,7 @@ void doHTML(const char *dir, Entry *root)
     dumpFile(dir, "icon1.gif", blueBall, sizeof(blueBall));
     dumpFile(dir, "icon2.gif", greyBall, sizeof(greyBall));
 
-    if(javaGraphs)
+    if(javaGraphs && !noClassGraph && relevantClassGraphs(root))
 	{
 	dumpFile(dir, "ClassGraph.class", ClassGraph_class,
 	    sizeof(ClassGraph_class));
@@ -2156,24 +2186,27 @@ void doHTML(const char *dir, Entry *root)
     writeTOC(f);
     fclose(f);
 
-    if(verb)
-	printf(_("Writing Class Hierarchy...\n"));
-
-    // Class heirarchy
-    buf = "HIER";
-    buf += htmlSuffix;
-    f = myOpen(dir, buf);
-    writeHIER(f);
-    fclose(f);
-
-    // Java class heirarchy
-    if(javaGraphs)
+    if(!noClassGraph && relevantClassGraphs(root))
+	// Class heirarchy
 	{
-	buf = "HIERjava";
+	if(verb)
+	    printf(_("Writing Class Hierarchy...\n"));
+
+	buf = "HIER";
 	buf += htmlSuffix;
 	f = myOpen(dir, buf);
-	writeHIERjava(f);
-	fclose(f);  
+	writeHIER(f);
+	fclose(f);
+
+	// Java class heirarchy
+	if(javaGraphs)
+	    {
+	    buf = "HIERjava";
+	    buf += htmlSuffix;
+	    f = myOpen(dir, buf);
+	    writeHIERjava(f);
+	    fclose(f);  
+	    }
 	}
 
     /* Render all the rest of the pages to HTML, and output a 'General' file
@@ -2185,7 +2218,7 @@ void doHTML(const char *dir, Entry *root)
     root->general = false;
 
     buf = GENERAL_NAME;
-    buf+= htmlSuffix;
+    buf += htmlSuffix;
     generalf = myOpen(dir, buf);
     if(header.length() == 0 && ownHeader.length() == 0)
         fprintf(generalf, "%s", generalHeader.c_str());
