@@ -60,6 +60,7 @@ void help()
     printf(_("  -I  --input FILE       read a list of input files from FILE\n"));
     printf(_("  -J  --java             parse Java instead of C/C++\n"));
     printf(_("  -nd --no-define        ignore `#define' macros\n"));
+    printf(_("  -ng --no-class-graph   do not generate class graph\n"));
     printf(_("  -p  --private          document private members\n"));
     printf(_("  -q  --quick            optimize for speed instead of size\n"));
     printf(_("  -Q  --quantel          Quantel extensions, folding & appended comments\n"));
@@ -103,7 +104,6 @@ void help()
     printf(_("  -et --title FILE       use content of FILE as TeX title page\n"));
     printf(_("  -D  --depth DEPTH      set minimum depth (number of levels) in TOC\n"));
     printf(_("  -l  --no-env           do not generate TeX environment\n"));
-    printf(_("  -ng --no-class-graph   do not generate class graph\n"));
     printf(_("  -o  --output FILE      set output file name\n"));
     printf(_("  -s  --source           generate source code listing\n"));
     printf(_("  -X  --hide-index       don't generate index at section start\n\n"));
@@ -157,6 +157,7 @@ int main(int argc, char **argv)
         { "java", no_argument, 0, 'J' },
         { "trivial-graphs", no_argument, 0, 'k' },
         { "no-defines", no_argument, 0, 'N' },
+        { "no-class-graph", no_argument, 0, '7' },
         { "private", no_argument, 0, 'p' },
         { "quick", no_argument, 0, 'q' },
         { "quantel", no_argument, 0, 'Q' },
@@ -199,7 +200,6 @@ int main(int argc, char **argv)
         { "title", required_argument, 0, '6' },
         { "depth", required_argument, 0, 'D' },
         { "no-env", no_argument, 0, 'l' },
-        { "no-class-graph", no_argument, 0, '7' },
         { "output", required_argument, 0, 'o' },
         { "source", no_argument, 0, 's' },
 	{ "hide-index", no_argument, 0, 'X' },
@@ -250,6 +250,9 @@ int main(int argc, char **argv)
 	    case 'N':
 		noDefines = true;
 		break;
+	    case '7':
+    		noClassGraph = true;
+		break;
 	    case 'n':
 		switch(optarg[0])
 		    {
@@ -420,9 +423,6 @@ int main(int argc, char **argv)
 		    }
     		texTitle = optarg;
 		break;
-	    case '7':
-    		noClassGraph = true;
-		break;
 	    case 'X':
 		hideIndexOnEverySection = true;
 		break;
@@ -653,5 +653,5 @@ int main(int argc, char **argv)
     if(verb)
 	printf(_("Done.\n"));
 
-    exit(0);
+    return 0;
 }
